@@ -1,10 +1,16 @@
+import importlib
 from abc import ABC, abstractmethod
 
+
 class Checker(ABC):
     @abstractmethod
     def check(self, value):
         raise NotImplementedError
 
+    @abstractmethod
+    def help(self) -> str:
+        raise NotImplementedError
+
 
 def get_checker(checker):
     if checker in DEFAULT_CHECKERS:
@@ -75,7 +81,6 @@ class And(Checker):
             result = checker.check(result)
         return result
 
-
     def help(self):
         return ' and '.join([x.help() for x in self.checkers])
 
@@ -94,6 +99,33 @@ class InRange(Checker):
 
         return f"between {self.low} and {self.high}"
 
+class Module(Checker):
+
+    def __init__(self):
+        pass
+
+    def check(self, value):
+        return importlib.import_module(value)
+
+    def help(self):
+        return "path to python module"
+
+class ImportedObject(Checker):
+
+    def __init__(self):
+        pass
+
+    def check(self, value):
+        path = value.split('.')
+        module = '.'.join(path[:-1])
+        imported = importlib.import_module(module)
+        return getattr(imported, path[-1])
+
+
+    def help(self):
+        return "path to python module and an object within"
+
+
 DEFAULT_CHECKERS = {
     int: Int(),
     float: Float(),
